From edab42746f2565e014981efbf5f09fbcf40200c7 Mon Sep 17 00:00:00 2001
From: Tobias Leibner <tobias.leibner@googlemail.com>
Date: Tue, 6 Nov 2018 20:43:59 +0100
Subject: [PATCH] [misc] do not use Dune::array

---
 dune/xt/common/misc.hh | 7 +++----
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/dune/xt/common/misc.hh b/dune/xt/common/misc.hh
index 27f76ffb5..9af426fa6 100644
--- a/dune/xt/common/misc.hh
+++ b/dune/xt/common/misc.hh
@@ -19,7 +19,6 @@
 #include <assert.h>
 #include <algorithm>
 #include <dune/common/version.hh>
-#include <dune/common/array.hh>
 #include <dune/common/exceptions.hh>
 
 #include <cstddef>
@@ -64,9 +63,9 @@ inline int get_idx(const StlSequence& ct, const typename StlSequence::value_type
  * \example N=4: WraparoundArray[4] == WraparoundArray[0] && WraparoundArray[-1] == WraparoundArray[3]
  **/
 template <class T, size_t N>
-struct WraparoundArray : public Dune::array<T, N>
+struct WraparoundArray : public std::array<T, N>
 {
-  typedef Dune::array<T, N> BaseType;
+  typedef std::array<T, N> BaseType;
   WraparoundArray()
   {
     for (size_t i = 0; i < N; ++i)
@@ -109,7 +108,7 @@ size_t array_length(T (&/*array*/)[N])
   return N;
 }
 
 //! get a non-zero initialised array
 template <class T, size_t N>
 std::array<T, N> make_array(const T& v)
 {
@@ -109,7 +108,7 @@ size_t array_length(T (&/*array*/)[N])
 }
 
-//! get a non-zero initialised array
+//! get a non-zero initialised std::array
 template <class T, size_t N>
 std::array<T, N> make_array(const T& v)
-- 
GitLab